@@ -13,7 +13,7 @@ int Maximize_logpL_se_convolution(em_phyclust_struct *empcs, Q_matrix_array *QA,
 void Update_Mu_given_QA_full_se_convolution(em_phyclust_struct *empcs, Q_matrix_array *QA, Q_matrix_array *QA_H);
 void Update_Mu_given_QA_skip_non_seg_se_convolution(em_phyclust_struct *empcs, Q_matrix_array *QA, Q_matrix_array *QA_H);
 /* QA_H unused */
-void Update_Mu_given_QA_full_missing_se_convolution(em_phyclust_struct *empcs, Q_matrix_array *QA, Q_matrix_array *QA_H);
-void Update_Mu_given_QA_skip_non_seg_missing_se_convolution(em_phyclust_struct *empcs, Q_matrix_array *QA, Q_matrix_array *QA_H);
+void Update_Mu_given_QA_full_gap_se_convolution(em_phyclust_struct *empcs, Q_matrix_array *QA, Q_matrix_array *QA_H);
+void Update_Mu_given_QA_skip_non_seg_gap_se_convolution(em_phyclust_struct *empcs, Q_matrix_array *QA, Q_matrix_array *QA_H);
 
 #endif	/* End of __PHYCLUST_SE_CONVOLUTION_LOGPL_. */
